# News Toolkit API

[Flutter News Toolkit](https://github.com/flutter/news_toolkit) is a fantastic tool for effortlessly creating news applications with Flutter. While the toolkit enables the straightforward creation of mobile applications, it requires an API server to fetch article and feed data.

This Python library provides a solution to that requirement. It asynchronously scrapes data from your website based on user access triggers, stores it in a database, and serves all the required APIs to be used with the Flutter News Toolkit.
